import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["children", "value"];
import React from 'react';
import { merge } from '@amaui/utils';
import { AmauiStyle, makeClassName, unit, rtl, sort, valueObject } from '@amaui/style';
import AmauiStyleContext from './AmauiStyleContext';

function makeAmauiStyle(element) {
  const amauiStyle = new AmauiStyle(element); // Add all the plugins

  amauiStyle.plugins.add = [makeClassName, unit, rtl, sort, valueObject];
  return amauiStyle;
}

export default function AmauiStyleProvider(props) {
  const {
    children,
    value: value_
  } = props,
        other = _objectWithoutProperties(props, _excluded);

  const ref = React.useRef();
  const [value, setValue] = React.useState(() => {
    if (value_ === undefined || !(value_ instanceof AmauiStyle)) return makeAmauiStyle();
    return value_;
  });
  const setId = React.useState(undefined)[1];
  React.useEffect(() => {
    if (ref.current) {
      value.element = ref.current; // Init

      value.init();
      setId(value.hash);
    }
  }, []);

  const update = function (updateValue) {
    let override = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

    if (updateValue !== undefined) {
      const valueNew = override ? updateValue : merge(updateValue, value);
      setValue(valueNew);
      return valueNew;
    }
  };

  return /*#__PURE__*/React.createElement(AmauiStyleContext.Provider, {
    value: [value, update]
  }, /*#__PURE__*/React.createElement("div", _extends({
    ref: ref
  }, other), children));
}